==> open-xchange-guard_2.4.2.orig.tar.bz2: open-xchange-guard-2.4.2/com.openexchange.guard.email.storage/src/com/openexchange/guard/email/storage/ogEmail/Email.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.email.storage.ogEmail;

/**
 * Represents a mapping between a user's ID and a user's email
 */
public class Email {

    private final String email;
    private final int userId;
    private final int contextId;
    private final int shardingId;

    /**
     * Constructor
     * 
     * @param email The user's email
     * @param userId The user's ID
     * @param contextId The user's context id
     * @param shardingId the shard/database id pointing to the database which
     *            contains the key data related to this email
     */
    public Email(String email, int userId, int contextId, int shardingId) {
        this.email = email;
        this.userId = userId;
        this.contextId = contextId;
        this.shardingId = shardingId;
    }

    /**
     * Gets the user's email
     * 
     * @return the user's email
     */
    public String getEmail() {
        return this.email;
    }

    /**
     * Gets the user's ID
     * 
     * @return the user's ID
     */
    public int getUserId() {
        return this.userId;
    }

    /**
     * Gets the user's context ID
     * 
     * @return the user's context ID
     */
    public int getContextId() {
        return this.contextId;
    }

    /**
     * The shard ID pointing to the database which contains the key information related to this email
     * 
     * @return the shard id
     */
    public int getShardingId() {
        return shardingId;
    }

}

==> open-xchange-guard_2.10.5.orig.tar.bz2: open-xchange-guard-2.10.5/com.openexchange.guard.email.storage/src/com/openexchange/guard/email/storage/ogEmail/Email.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.email.storage.ogEmail;

import java.io.Serializable;

/**
 * Represents a mapping between a user's ID and a user's email
 */
public class Email implements Serializable {

    /**
     * serialVersionUID
     */
    private static final long serialVersionUID = 5621725946814838901L;

    private final String email;
    private final int userId;
    private final int contextId;
    private final int shardingId;

    /**
     * Constructor
     *
     * @param email The user's email
     * @param userId The user's ID
     * @param contextId The user's context id
     * @param shardingId the shard/database id pointing to the database which
     *            contains the key data related to this email
     */
    public Email(String email, int userId, int contextId, int shardingId) {
        this.email = email;
        this.userId = userId;
        this.contextId = contextId;
        this.shardingId = shardingId;
    }

    /**
     * Gets the user's email
     *
     * @return the user's email
     */
    public String getEmail() {
        return this.email;
    }

    /**
     * Gets the user's ID
     *
     * @return the user's ID
     */
    public int getUserId() {
        return this.userId;
    }

    /**
     * Gets the user's context ID
     *
     * @return the user's context ID
     */
    public int getContextId() {
        return this.contextId;
    }

    /**
     * The shard ID pointing to the database which contains the key information related to this email
     *
     * @return the shard id
     */
    public int getShardingId() {
        return shardingId;
    }

}
